@@ -2,7 +2,7 @@ package Test2::Harness::UI::Controller::Stream;
 use strict;
 use warnings;
 
-our $VERSION = '0.000097';
+our $VERSION = '0.000098';
 
 use Data::GUID;
 use List::Util qw/max/;
@@ -124,11 +124,11 @@ sub stream_runs {
         }
         else {
             my $u_rs = $schema->resultset('User');
-            $user //= eval { $u_rs->search({user_id => $id})->first };
+            $user //= eval { $u_rs->search({user_id  => $id})->first };
             $user //= eval { $u_rs->search({username => $id})->first };
 
             if ($user) {
-                $params{search_base} = $params{search_base}->search_rs({user_id => $user->user_id});
+                $params{search_base} = $params{search_base}->search_rs({'me.user_id' => $user->user_id});
             }
             else {
                 $run_id //= $id;
